@@ -14,6 +14,7 @@ Usage::
 import sys
 from typing import Any, Dict, List, Type, overload
 
+from botocore.client import ClientMeta
 from botocore.exceptions import ClientError as Boto3ClientError
 from botocore.paginate import Paginator as Boto3Paginator
 
@@ -79,14 +80,15 @@ class Exceptions:
 
 class ForecastServiceClient:
     """
-    [ForecastService.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.36/reference/services/forecast.html#ForecastService.Client)
+    [ForecastService.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/forecast.html#ForecastService.Client)
     """
 
+    meta: ClientMeta
     exceptions: Exceptions
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.36/reference/services/forecast.html#ForecastService.Client.can_paginate)
+        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/forecast.html#ForecastService.Client.can_paginate)
         """
 
     def create_dataset(
@@ -108,7 +110,7 @@ class ForecastServiceClient:
         Tags: List["TagTypeDef"] = None,
     ) -> CreateDatasetResponseTypeDef:
         """
-        [Client.create_dataset documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.36/reference/services/forecast.html#ForecastService.Client.create_dataset)
+        [Client.create_dataset documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/forecast.html#ForecastService.Client.create_dataset)
         """
 
     def create_dataset_group(
@@ -127,7 +129,7 @@ class ForecastServiceClient:
         Tags: List["TagTypeDef"] = None,
     ) -> CreateDatasetGroupResponseTypeDef:
         """
-        [Client.create_dataset_group documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.36/reference/services/forecast.html#ForecastService.Client.create_dataset_group)
+        [Client.create_dataset_group documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/forecast.html#ForecastService.Client.create_dataset_group)
         """
 
     def create_dataset_import_job(
@@ -139,7 +141,7 @@ class ForecastServiceClient:
         Tags: List["TagTypeDef"] = None,
     ) -> CreateDatasetImportJobResponseTypeDef:
         """
-        [Client.create_dataset_import_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.36/reference/services/forecast.html#ForecastService.Client.create_dataset_import_job)
+        [Client.create_dataset_import_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/forecast.html#ForecastService.Client.create_dataset_import_job)
         """
 
     def create_forecast(
@@ -150,7 +152,7 @@ class ForecastServiceClient:
         Tags: List["TagTypeDef"] = None,
     ) -> CreateForecastResponseTypeDef:
         """
-        [Client.create_forecast documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.36/reference/services/forecast.html#ForecastService.Client.create_forecast)
+        [Client.create_forecast documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/forecast.html#ForecastService.Client.create_forecast)
         """
 
     def create_forecast_export_job(
@@ -161,7 +163,7 @@ class ForecastServiceClient:
         Tags: List["TagTypeDef"] = None,
     ) -> CreateForecastExportJobResponseTypeDef:
         """
-        [Client.create_forecast_export_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.36/reference/services/forecast.html#ForecastService.Client.create_forecast_export_job)
+        [Client.create_forecast_export_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/forecast.html#ForecastService.Client.create_forecast_export_job)
         """
 
     def create_predictor(
@@ -180,71 +182,71 @@ class ForecastServiceClient:
         Tags: List["TagTypeDef"] = None,
     ) -> CreatePredictorResponseTypeDef:
         """
-        [Client.create_predictor documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.36/reference/services/forecast.html#ForecastService.Client.create_predictor)
+        [Client.create_predictor documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/forecast.html#ForecastService.Client.create_predictor)
         """
 
     def delete_dataset(self, DatasetArn: str) -> None:
         """
-        [Client.delete_dataset documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.36/reference/services/forecast.html#ForecastService.Client.delete_dataset)
+        [Client.delete_dataset documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/forecast.html#ForecastService.Client.delete_dataset)
         """
 
     def delete_dataset_group(self, DatasetGroupArn: str) -> None:
         """
-        [Client.delete_dataset_group documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.36/reference/services/forecast.html#ForecastService.Client.delete_dataset_group)
+        [Client.delete_dataset_group documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/forecast.html#ForecastService.Client.delete_dataset_group)
         """
 
     def delete_dataset_import_job(self, DatasetImportJobArn: str) -> None:
         """
-        [Client.delete_dataset_import_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.36/reference/services/forecast.html#ForecastService.Client.delete_dataset_import_job)
+        [Client.delete_dataset_import_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/forecast.html#ForecastService.Client.delete_dataset_import_job)
         """
 
     def delete_forecast(self, ForecastArn: str) -> None:
         """
-        [Client.delete_forecast documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.36/reference/services/forecast.html#ForecastService.Client.delete_forecast)
+        [Client.delete_forecast documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/forecast.html#ForecastService.Client.delete_forecast)
         """
 
     def delete_forecast_export_job(self, ForecastExportJobArn: str) -> None:
         """
-        [Client.delete_forecast_export_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.36/reference/services/forecast.html#ForecastService.Client.delete_forecast_export_job)
+        [Client.delete_forecast_export_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/forecast.html#ForecastService.Client.delete_forecast_export_job)
         """
 
     def delete_predictor(self, PredictorArn: str) -> None:
         """
-        [Client.delete_predictor documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.36/reference/services/forecast.html#ForecastService.Client.delete_predictor)
+        [Client.delete_predictor documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/forecast.html#ForecastService.Client.delete_predictor)
         """
 
     def describe_dataset(self, DatasetArn: str) -> DescribeDatasetResponseTypeDef:
         """
-        [Client.describe_dataset documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.36/reference/services/forecast.html#ForecastService.Client.describe_dataset)
+        [Client.describe_dataset documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/forecast.html#ForecastService.Client.describe_dataset)
         """
 
     def describe_dataset_group(self, DatasetGroupArn: str) -> DescribeDatasetGroupResponseTypeDef:
         """
-        [Client.describe_dataset_group documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.36/reference/services/forecast.html#ForecastService.Client.describe_dataset_group)
+        [Client.describe_dataset_group documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/forecast.html#ForecastService.Client.describe_dataset_group)
         """
 
     def describe_dataset_import_job(
         self, DatasetImportJobArn: str
     ) -> DescribeDatasetImportJobResponseTypeDef:
         """
-        [Client.describe_dataset_import_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.36/reference/services/forecast.html#ForecastService.Client.describe_dataset_import_job)
+        [Client.describe_dataset_import_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/forecast.html#ForecastService.Client.describe_dataset_import_job)
         """
 
     def describe_forecast(self, ForecastArn: str) -> DescribeForecastResponseTypeDef:
         """
-        [Client.describe_forecast documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.36/reference/services/forecast.html#ForecastService.Client.describe_forecast)
+        [Client.describe_forecast documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/forecast.html#ForecastService.Client.describe_forecast)
         """
 
     def describe_forecast_export_job(
         self, ForecastExportJobArn: str
     ) -> DescribeForecastExportJobResponseTypeDef:
         """
-        [Client.describe_forecast_export_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.36/reference/services/forecast.html#ForecastService.Client.describe_forecast_export_job)
+        [Client.describe_forecast_export_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/forecast.html#ForecastService.Client.describe_forecast_export_job)
         """
 
     def describe_predictor(self, PredictorArn: str) -> DescribePredictorResponseTypeDef:
         """
-        [Client.describe_predictor documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.36/reference/services/forecast.html#ForecastService.Client.describe_predictor)
+        [Client.describe_predictor documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/forecast.html#ForecastService.Client.describe_predictor)
         """
 
     def generate_presigned_url(
@@ -255,74 +257,74 @@ class ForecastServiceClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.36/reference/services/forecast.html#ForecastService.Client.generate_presigned_url)
+        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/forecast.html#ForecastService.Client.generate_presigned_url)
         """
 
     def get_accuracy_metrics(self, PredictorArn: str) -> GetAccuracyMetricsResponseTypeDef:
         """
-        [Client.get_accuracy_metrics documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.36/reference/services/forecast.html#ForecastService.Client.get_accuracy_metrics)
+        [Client.get_accuracy_metrics documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/forecast.html#ForecastService.Client.get_accuracy_metrics)
         """
 
     def list_dataset_groups(
         self, NextToken: str = None, MaxResults: int = None
     ) -> ListDatasetGroupsResponseTypeDef:
         """
-        [Client.list_dataset_groups documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.36/reference/services/forecast.html#ForecastService.Client.list_dataset_groups)
+        [Client.list_dataset_groups documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/forecast.html#ForecastService.Client.list_dataset_groups)
         """
 
     def list_dataset_import_jobs(
         self, NextToken: str = None, MaxResults: int = None, Filters: List[FilterTypeDef] = None
     ) -> ListDatasetImportJobsResponseTypeDef:
         """
-        [Client.list_dataset_import_jobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.36/reference/services/forecast.html#ForecastService.Client.list_dataset_import_jobs)
+        [Client.list_dataset_import_jobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/forecast.html#ForecastService.Client.list_dataset_import_jobs)
         """
 
     def list_datasets(
         self, NextToken: str = None, MaxResults: int = None
     ) -> ListDatasetsResponseTypeDef:
         """
-        [Client.list_datasets documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.36/reference/services/forecast.html#ForecastService.Client.list_datasets)
+        [Client.list_datasets documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/forecast.html#ForecastService.Client.list_datasets)
         """
 
     def list_forecast_export_jobs(
         self, NextToken: str = None, MaxResults: int = None, Filters: List[FilterTypeDef] = None
     ) -> ListForecastExportJobsResponseTypeDef:
         """
-        [Client.list_forecast_export_jobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.36/reference/services/forecast.html#ForecastService.Client.list_forecast_export_jobs)
+        [Client.list_forecast_export_jobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/forecast.html#ForecastService.Client.list_forecast_export_jobs)
         """
 
     def list_forecasts(
         self, NextToken: str = None, MaxResults: int = None, Filters: List[FilterTypeDef] = None
     ) -> ListForecastsResponseTypeDef:
         """
-        [Client.list_forecasts documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.36/reference/services/forecast.html#ForecastService.Client.list_forecasts)
+        [Client.list_forecasts documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/forecast.html#ForecastService.Client.list_forecasts)
         """
 
     def list_predictors(
         self, NextToken: str = None, MaxResults: int = None, Filters: List[FilterTypeDef] = None
     ) -> ListPredictorsResponseTypeDef:
         """
-        [Client.list_predictors documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.36/reference/services/forecast.html#ForecastService.Client.list_predictors)
+        [Client.list_predictors documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/forecast.html#ForecastService.Client.list_predictors)
         """
 
     def list_tags_for_resource(self, ResourceArn: str) -> ListTagsForResourceResponseTypeDef:
         """
-        [Client.list_tags_for_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.36/reference/services/forecast.html#ForecastService.Client.list_tags_for_resource)
+        [Client.list_tags_for_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/forecast.html#ForecastService.Client.list_tags_for_resource)
         """
 
     def tag_resource(self, ResourceArn: str, Tags: List["TagTypeDef"]) -> Dict[str, Any]:
         """
-        [Client.tag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.36/reference/services/forecast.html#ForecastService.Client.tag_resource)
+        [Client.tag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/forecast.html#ForecastService.Client.tag_resource)
         """
 
     def untag_resource(self, ResourceArn: str, TagKeys: List[str]) -> Dict[str, Any]:
         """
-        [Client.untag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.36/reference/services/forecast.html#ForecastService.Client.untag_resource)
+        [Client.untag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/forecast.html#ForecastService.Client.untag_resource)
         """
 
     def update_dataset_group(self, DatasetGroupArn: str, DatasetArns: List[str]) -> Dict[str, Any]:
         """
-        [Client.update_dataset_group documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.36/reference/services/forecast.html#ForecastService.Client.update_dataset_group)
+        [Client.update_dataset_group documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/forecast.html#ForecastService.Client.update_dataset_group)
         """
 
     @overload
@@ -330,7 +332,7 @@ class ForecastServiceClient:
         self, operation_name: Literal["list_dataset_groups"]
     ) -> ListDatasetGroupsPaginator:
         """
-        [Paginator.ListDatasetGroups documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.36/reference/services/forecast.html#ForecastService.Paginator.ListDatasetGroups)
+        [Paginator.ListDatasetGroups documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/forecast.html#ForecastService.Paginator.ListDatasetGroups)
         """
 
     @overload
@@ -338,13 +340,13 @@ class ForecastServiceClient:
         self, operation_name: Literal["list_dataset_import_jobs"]
     ) -> ListDatasetImportJobsPaginator:
         """
-        [Paginator.ListDatasetImportJobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.36/reference/services/forecast.html#ForecastService.Paginator.ListDatasetImportJobs)
+        [Paginator.ListDatasetImportJobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/forecast.html#ForecastService.Paginator.ListDatasetImportJobs)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_datasets"]) -> ListDatasetsPaginator:
         """
-        [Paginator.ListDatasets documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.36/reference/services/forecast.html#ForecastService.Paginator.ListDatasets)
+        [Paginator.ListDatasets documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/forecast.html#ForecastService.Paginator.ListDatasets)
         """
 
     @overload
@@ -352,19 +354,19 @@ class ForecastServiceClient:
         self, operation_name: Literal["list_forecast_export_jobs"]
     ) -> ListForecastExportJobsPaginator:
         """
-        [Paginator.ListForecastExportJobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.36/reference/services/forecast.html#ForecastService.Paginator.ListForecastExportJobs)
+        [Paginator.ListForecastExportJobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/forecast.html#ForecastService.Paginator.ListForecastExportJobs)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_forecasts"]) -> ListForecastsPaginator:
         """
-        [Paginator.ListForecasts documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.36/reference/services/forecast.html#ForecastService.Paginator.ListForecasts)
+        [Paginator.ListForecasts documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/forecast.html#ForecastService.Paginator.ListForecasts)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_predictors"]) -> ListPredictorsPaginator:
         """
-        [Paginator.ListPredictors documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.36/reference/services/forecast.html#ForecastService.Paginator.ListPredictors)
+        [Paginator.ListPredictors documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/forecast.html#ForecastService.Paginator.ListPredictors)
         """
 
     def get_paginator(self, operation_name: str) -> Boto3Paginator:
