@@ -53,6 +53,7 @@ __all__ = (
     "SchemaTypeDef",
     "StatisticsTypeDef",
     "SupplementaryFeatureTypeDef",
+    "TagTypeDef",
     "TestWindowSummaryTypeDef",
     "WeightedQuantileLossTypeDef",
     "WindowSummaryTypeDef",
@@ -76,6 +77,7 @@ __all__ = (
     "ListForecastExportJobsResponseTypeDef",
     "ListForecastsResponseTypeDef",
     "ListPredictorsResponseTypeDef",
+    "ListTagsForResourceResponseTypeDef",
     "PaginatorConfigTypeDef",
 )
 
@@ -349,6 +351,8 @@ StatisticsTypeDef = TypedDict(
 
 SupplementaryFeatureTypeDef = TypedDict("SupplementaryFeatureTypeDef", {"Name": str, "Value": str})
 
+TagTypeDef = TypedDict("TagTypeDef", {"Key": str, "Value": str})
+
 TestWindowSummaryTypeDef = TypedDict(
     "TestWindowSummaryTypeDef",
     {"TestWindowStart": datetime, "TestWindowEnd": datetime, "Status": str, "Message": str},
@@ -563,6 +567,10 @@ ListPredictorsResponseTypeDef = TypedDict(
     total=False,
 )
 
+ListTagsForResourceResponseTypeDef = TypedDict(
+    "ListTagsForResourceResponseTypeDef", {"Tags": List["TagTypeDef"]}, total=False
+)
+
 PaginatorConfigTypeDef = TypedDict(
     "PaginatorConfigTypeDef", {"MaxItems": int, "PageSize": int, "StartingToken": str}, total=False
 )
